@@ -8,6 +8,7 @@ no warnings;            #   Perl will complain about attribute being redefined
 use Symbol;
 use Spiffy '-base';
 use Data::Dumper;
+#use Log::Log4perl;
 
 our $VERSION = 1.0;
 our @EXPORT = qw(new internal attribute populate Dumper error);
@@ -40,6 +41,8 @@ sub new
 
 
 sub populate 
+#   populate $self->ACCESSOR with arguments in $args.
+#   This is usually called by init() after the args have been parsed. 
 {
     my ($self, $args) = @_;
 
@@ -52,7 +55,9 @@ sub populate
     }
 }
 
-sub attribute {
+sub attribute 
+#   See Spiffy or better yet, IO::All where this code came from
+{
     my $package = caller;
     my ($attribute, $default) = @_;
     no strict 'refs';
