@@ -2,7 +2,7 @@ package Data::All::IO::Base;
 
 #   Base package for all format modules
 
-#   $Id: Base.pm,v 1.1.1.1.8.1 2004/04/16 17:10:34 dgrant Exp $
+#   $Id: Base.pm,v 1.1.1.1.8.3 2004/04/28 22:50:47 dgrant Exp $
 
 use strict;
 use warnings;
@@ -68,8 +68,6 @@ sub getrecords(;$$)
     
     $self->__curpos($start);
     
-    
-    
     warn ' -> using fields:', join(',', @{ $self->fields });
     
     while ($record = $self->getrecord_hash())
@@ -85,9 +83,10 @@ sub getrecords(;$$)
 sub putrecords()
 {
     my $self = shift;
-    my $records = shift;
-    my $start = shift || 0;
-    my $count = shift || $#{ $records }+1;
+    my ($records, $options) = @_;
+
+    my $start = 0;
+    my $count = $#{ $records }+1;
 
     die("$self->putrecords() needs records") unless ($#{ $records }+1);
         
@@ -96,7 +95,7 @@ sub putrecords()
     my $record;
     while ($count--)
     {
-        $self->putrecord($records->[ $start++ ]);
+        $self->putrecord($records->[ $start++ ], $options);
     }
 }
 
@@ -119,7 +118,7 @@ sub init()
     populate $self => $args;
 
     warn " -> path:", join ', ', @{ $self->path() };
-    warn " -> format:", $self->format->{'type'};
+    warn " -> format:", $self->format()->{'type'};
     warn " -> io:", $self->ioconf->{'type'};
     
     $self->__FORMAT($self->_load_format())  
@@ -135,6 +134,9 @@ internal 'added_fields'         => {};
 
 
 #   $Log: Base.pm,v $
+#   Revision 1.1.1.1.8.3  2004/04/28 22:50:47  dgrant
+#   - Added the option to process files record by record rather than atomically
+#
 #   Revision 1.1.1.1.8.1  2004/04/16 17:10:34  dgrant
 #   - Merging libperl-016 changes into the libperl-1-current trunk
 #
